# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 2.x     | :white_check_mark: |
| < 2.x   | :x:                |

## Reporting a Vulnerability

Follow these steps:

1. Start by [emailing developers](mailto:mailsforabhinav+proxy@gmail.com)
2. If unresponsive, [create a public issue](https://github.com/abhinavsingh/proxy.py/issues/new/choose) without disclosure about the vulnerability itself.
3. [Pull requests](https://github.com/abhinavsingh/proxy.py/pulls) are always welcome
